@@ -3,7 +3,7 @@
 import logging
 from typing import Any
 from collections import abc
-import pydantic
+import pydantic.json
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -29,6 +29,7 @@ def encode_pydantic_obj(obj: Any) -> Any:
     the need for a special encoder.
     """
     try:
+        # pylint: disable=c-extension-no-member
         result = pydantic.json.pydantic_encoder(obj)
     except TypeError:
         result = obj
